;****************************************************************************
;*									    *
;* 	TITLE: 		WF96CLK.ASM					    *
;*									    *
;* 	PURPOSE: 							    *
;*	This file is to be included in both WF96IRQ.ASM and WF96FLVC.ASM,   *
;*	to provide all parameters that are clock frequency dependant.	    *
;*	It has been created to support versions 2.00 and later of 	    *
;*	ConfigurACE II, to allow clock frequency change.		    *
;*									    *
;*	AUTHOR:		FRR/PDU						    *
;*									    *
;*	REVISION HISTORY:						    *
;*									    *
;*	25APR94	  FRR	Created						    *
;*									    *
;****************************************************************************
;	WARNING FOR USERS OF CONFIGURACE:	DON'T CHANGE THIS FILE				
;	--------------------------------				
;	The structure of this file must match the structure of HEX file,
;	this is not meant to be modified by the user, unlike WF96PROF.ASM.
;
;****************************************************************************
;	WARNING FOR S/W DEVELOPPERS				
;	---------------------------				
;	Changes in this module may affect compatibility with ConfigurACE,
;	please read complete instructions in note #1338 before any
;	significant change and take care of the following:
;	- don't change these keywords/macros/equates:
;	CLOCK_FREQUENCY, MAKE_PTG, Bxxx_INDEX, HERE_IS_FLASH
;	- ConfigurACE does not handle priority between operators in formulas,
;	2+3/5 is interpreted as (2+3)/5 by ConfigurACE and as 2+(3/5) by
;	the assembler, so you'd better USE BRACKETS.
;	
;****************************************************************************

.IFDEF	HERE_IS_FLASH	; This equate must be defined in FLVC module before
			; the .INCLUDE statement, so we now what table has
			; to be included.
			; This is to avoid having two separate include files.

START_INTERVAL:
	.DW	 (((CLOCK_FREQUENCY/32)*625)/100000)	; interval = 6.25 ms

FL_DTE_COUNTS:
        MAKE_PTG        9600    	;Parallel C39 7 (DEFAULT)

TIME_IN_INT:				; nominal time spend inside interupt
.IFZ	PARALLEL
	.DW	 ((CLOCK_FREQUENCY/32)*100)/1000	; Serial interval for
	.DW	 ((CLOCK_FREQUENCY/32)*100)/1000	; VFC lower DTE speeds.
	.DW	 ((CLOCK_FREQUENCY/32)*100)/1000	; interval =100.0 ms
	.DW	 ((CLOCK_FREQUENCY/32)*100)/1000	; interval =100.0 ms
	.DW	 ((CLOCK_FREQUENCY/32)*109)/1000	; interval =109.0 ms
	.DW	 ((CLOCK_FREQUENCY/32)*55)/1000		; interval = 55.0 ms
	.DW	 ((CLOCK_FREQUENCY/32)*27)/1000		; interval = 27.0 ms
.ELSE
	.DW	 ((CLOCK_FREQUENCY/32)*13)/1000		; interval = 13.0 ms
.ENDIF

TIME_OFF_INT:		; nominal time spend inside interupt
	.DW	 ((CLOCK_FREQUENCY/32)*13)/1000		; interval = 13.0 ms
	
TRAILING_TIME:		; time equivalent to 6 characters at DTE speed
	.IFZ	PARALLEL
	.DW	 ((CLOCK_FREQUENCY/32)*50)/1000		; interval = 50.0 ms
	.DW	 ((CLOCK_FREQUENCY/32)*25)/1000		; interval = 25.0 ms
	.DW	 ((CLOCK_FREQUENCY/32)*125)/10000	; interval = 12.5 ms
	.DW	 ((CLOCK_FREQUENCY/32)*625)/100000	; interval = 6.25 ms
	.DW	 ((CLOCK_FREQUENCY/32)*312)/100000	; interval = 3.12 ms
	.DW	 ((CLOCK_FREQUENCY/32)*156)/100000	; interval = 1.56 ms
	.DW	 ((CLOCK_FREQUENCY/32)*104)/100000	; interval = 1.04 ms
	.ELSE
	.DW	 ((CLOCK_FREQUENCY/32)*52)/100000	; interval = 0.52 ms
	.ENDIF
;
;-----------------------------------------------------------------------------;
;	*** WARNING: This table must fit below the VECTOR table.  ***	      ;
;		If the length increases past $30 (FFF0) adjust both the	      ;
;		linker-file and the FLASH loader.			      ;
;-----------------------------------------------------------------------------;

.ELSE		; include into IRQ file

;WARNING:      DO NOT REFER TO CLOCK_FREQUENCY ANYWHERE ELSE IN THE CODE,
;		OTHERWISE WE WILL NO LONGER BE ABLE TO CHANGE THE CLOCK
;		WITH CONFIGURACE.

START_INTERVAL_F:		; Used for Flash only but put here
				; intentionally without conditionals
;--------------------------------------------------------------------------;
;	.DW	 ((CLOCK_FREQUENCY*625)/(100000*32))	; interval = 6.25 ms
;--------------------------------------------------------------------------;
	.DW	CLOCK_FREQUENCY/(160*32)		; Simplified for 
							; PLC compatibility
;========================================================================
;       D T E   P T G   C O U N T E R   T A B L E
.IF	P16550

DTE_COUNTS:			; Convert DTE BAUD RATE PTG COUNTS TABLE
                                ; Each entry is WORD long
	MAKE_PTG        230400 	; 230.4K bps
	MAKE_PTG	300	;  0:   300 bps
	MAKE_PTG	600	;  1:   600 bps  
	MAKE_PTG	1200	;  2:  1200 bps
	MAKE_PTG	2400	;  3:  2400 bps 
	MAKE_PTG	4800	;  4:  4800 bps
	MAKE_PTG	7200	;  5:  7200 bps
ptg9600:			; use for RHSI
	MAKE_PTG	9600	;  6:  9600 bps
	MAKE_PTG	12000	;  7: 12000 bps
	MAKE_PTG	14400	;  8: 14400 bps
	MAKE_PTG	19200	;  9: 19200 bps
	MAKE_PTG	38400	; 10: 38400 bps
.IFDEF	CSM			; Start CSM
	MAKE_PTG       230400 	; 11:230400 bps for parallel CSM only
	MAKE_PTG       460800 	; 12:460800 bps for parallel CSM only
.ELSE				; Start ACi/ACFSP
	MAKE_PTG	57600 	; 11: 57600 bps
	MAKE_PTG       115200 	; 12:115200 bps
.ENDIF ;CSM
ptg400000:			; use for RHSI
	MAKE_PTG	400000	
	MAKE_PTG	28800	; 13: 28800 bps
.ENDIF

.IFZ PARALLEL                           ;If Serial then used by Autobaud

DTE_COUNTS:     ; DTE BAUD RATE PTG COUNTS TABLE

        MAKE_PTG        75      ;  0 (75)
        MAKE_PTG        150     ;  1 (150)
        MAKE_PTG        300     ;  2 (300)
        MAKE_PTG        600     ;  3 (600)
        MAKE_PTG        1200    ;  4 (1200)
        MAKE_PTG        2400    ;  5 (2400)
        MAKE_PTG        4800    ;  6 (4800)
        MAKE_PTG        9600    ;  7 (9600 DEFAULT)
        MAKE_PTG        19200   ;  8 (19200)
        MAKE_PTG        38400   ;  9 (38400)
        MAKE_PTG        110     ; 10 (110)
        MAKE_PTG        135     ; 11 (135 really 134.5)
        MAKE_PTG        3600    ; 12 (3600)
        MAKE_PTG        7200    ; 13 (7200)
	MAKE_PTG        12000   ; 14 (12000 Doesn't work with PC's)
        MAKE_PTG        14400   ; 15 (14400)
        MAKE_PTG        50      ; 16 (50)
        MAKE_PTG        57600   ; 17 (57600)
	MAKE_PTG_115200	115200	; 18 (115200 doesn't work wait for L39)
				;    use different macro since PTG not divided by 3
	MAKE_PTG	1	; 19 (split1) Just to get the index right	
	MAKE_PTG	1	; 20 (split2) Just to get the index right	
	MAKE_PTG	16800	; 21 (16800)
	MAKE_PTG	21600	; 22 (21600)
	MAKE_PTG	24000	; 23 (24000)
	MAKE_PTG	26800	; 24 (26400)
	MAKE_PTG	28800	; 25 (28800)
	MAKE_PTG	20800	; 26 (20800)
	MAKE_PTG        31200   ; 27 (31200)
	MAKE_PTG        41600   ; 28 (41600)
	MAKE_PTG        51200   ; 29 (51200)
	MAKE_PTG	62400	; 30 (62400)
    .IFDEF	X2CLOCK
	MAKE_PTG_115200	230400	; 31 (230400 doesn't work wait for L39)
				;    use different macro since PTG not divided by 3
    .ENDIF

RATE_TABLE:             ;Used to calculate 16-bit counter value for UART.
                        ;For each rate, 5 bytes are used: first byte is
                        ;BAUD_RATE as used in DTE_SPEED (WF96DTE), the next
                        ;2 bytes define a 16-bit value which is the exact
                        ;(standard) 16-bit value that needs be programmed
                        ;in the timer for an exact bit cell width
                        ;Finally, the last 2 bytes contain the
                        ;min counter value for which a rate is recognized.
                        ;This value is compared against the value of the
                        ;interval timer that contains start bit width.

	.DB	$FF					; Wrong Index
	.DW	$FFFF					; Wrong Timer
	.DW	$FFFF					; Wrong Timer

RT_300:
        .DB     B300_INDEX				; 300 bps

   .IF (CLOCK_FREQUENCY < 19660800)
	.DW     CLOCK_FREQUENCY/300
   .ELSE       
	.DW     CLOCK_FREQUENCY/300/32			;Overflow switches to divide by 32
   .ENDIF
   .IF (CLOCK_FREQUENCY < 16588800)
        .DW     CLOCK_FREQUENCY/250			; Lowest possible value
							; for timer!
   .ELSE
        .DW     FFFFH			; Overflow - Use MAX value!
   .ENDIF

        .DB     B600_INDEX				; 600 bps
        .DW     CLOCK_FREQUENCY/600
        .DW     CLOCK_FREQUENCY/(600-((600-300)/3))
        .DB     B1200_INDEX				; 1200 bps
        .DW     CLOCK_FREQUENCY/1200
        .DW     CLOCK_FREQUENCY/(1200-((1200-600)/3))
        .DB     B2400_INDEX				; 2400 bps
        .DW     CLOCK_FREQUENCY/2400
        .DW     CLOCK_FREQUENCY/(2400-((2400-1200)/3))
        .DB     B4800_INDEX				; 4800 bps
        .DW     CLOCK_FREQUENCY/4800
        .DW     CLOCK_FREQUENCY/(4800-((4800-2400)/3))
        .DB     B7200_INDEX				; 7200 bps
        .DW     CLOCK_FREQUENCY/7200
        .DW     CLOCK_FREQUENCY/(7200-((7200-4800)/3))
        .DB     B9600_INDEX				; 9600 bps
        .DW     CLOCK_FREQUENCY/9600
        .DW     CLOCK_FREQUENCY/(9600-((9600-7200)/2))
        .DB     B12000_INDEX				; 12000 bps
        .DW     CLOCK_FREQUENCY/12000
        .DW     CLOCK_FREQUENCY/(12000-((12000-9600)/2))
RT_14400:
        .DB     B14400_INDEX				; 14400 bps
        .DW     CLOCK_FREQUENCY/14400
        .DW     CLOCK_FREQUENCY/(14400-((14400-12000)/2))
RT_16800:
        .DB     B16800_INDEX				; 16800 bps
	.DW	CLOCK_FREQUENCY/16800
        .DW     CLOCK_FREQUENCY/(16800-((16800-14400)/2))
RT_19200:
        .DB     B19200_INDEX				; 19200 bps
        .DW     CLOCK_FREQUENCY/19200
        .DW     CLOCK_FREQUENCY/(19200-((19200-16800)/2))
RT_20800: 
	.DB     B20800_INDEX				; 20800 bps (%N1)
        .DW     CLOCK_FREQUENCY/20800
        .DW     CLOCK_FREQUENCY/(20800-((20800-15600)/2))
RT_21600:
        .DB     B21600_INDEX				; 21600 bps
	.DW	CLOCK_FREQUENCY/21600
        .DW     CLOCK_FREQUENCY/(21600-((21600-19200)/2))
        .DB     B24000_INDEX				; 24000 bps
	.DW	CLOCK_FREQUENCY/24000
        .DW     CLOCK_FREQUENCY/(24000-((24000-21600)/2))
        .DB     B26400_INDEX				; 26400 bps
	.DW	CLOCK_FREQUENCY/26400
        .DW     CLOCK_FREQUENCY/(26400-((26400-24000)/2))
RT_28800:
        .DB     B28800_INDEX				; 28800 bps
	.DW	CLOCK_FREQUENCY/28800
        .DW     CLOCK_FREQUENCY/(28800-((28800-26400)/2))
RT_31200:
        .DB     B31200_INDEX				; 31200 bps (%N1)
        .DW     CLOCK_FREQUENCY/31200
        .DW     CLOCK_FREQUENCY/(31200-((31200-24960)/2))
RT_38400:
        .DB     B38400_INDEX				; 38400 bps
        .DW     CLOCK_FREQUENCY/38400
        .DW     CLOCK_FREQUENCY/(38400-((38400-28800)/2))
RT_41600:
        .DB     B41600_INDEX				; 41600 bps (%N1)
        .DW     CLOCK_FREQUENCY/41600
        .DW     CLOCK_FREQUENCY/(41600-((41600-31200)/2))
RT_51200:
        .DB     B51200_INDEX				; 51200 bps (%N2)
        .DW     CLOCK_FREQUENCY/51200
        .DW     CLOCK_FREQUENCY/(51200-((51200-38400)/2))
RT_57600:
        .DB     B57600_INDEX				; 57600 bps
        .DW     CLOCK_FREQUENCY/57600
        .DW     CLOCK_FREQUENCY/(57600-((57600-38400)/2))
RT_62400:
        .DB     B62400_INDEX				; 62400 bps (%N1)
        .DW     CLOCK_FREQUENCY/62400
        .DW     CLOCK_FREQUENCY/(62400-((62400-41600)/2))
RT_115200:
        .DB     B115200_INDEX				; 115200 bps
        .DW     CLOCK_FREQUENCY/115200
        .DW     CLOCK_FREQUENCY/(115200-((115200-57600)/2))

    .IFDEF	X2CLOCK
RT_230400:
        .DB     B230400_INDEX				; 230400 bps
        .DW     CLOCK_FREQUENCY/230400
        .DW     CLOCK_FREQUENCY/(230400-((230400-115200)/2))
    .ENDIF
     
HI_RATE_INDEX:  .EQU    $-RATE_TABLE-1

    .IFDEF	X2CLOCK
RT_230400_X:	.EQU	RT_230400-RATE_TABLE+4
    .ENDIF

RT_115200_X:	.EQU	RT_115200-RATE_TABLE+4
     
RT_62400_X:	.EQU	RT_62400-RATE_TABLE+4
RT_57600_X:	.EQU	RT_57600-RATE_TABLE+4
RT_51200_X:	.EQU	RT_51200-RATE_TABLE+4
RT_41600_X:	.EQU	RT_41600-RATE_TABLE+4
RT_38400_X:	.EQU	RT_38400-RATE_TABLE+4
RT_31200_X:	.EQU	RT_31200-RATE_TABLE+4
RT_28800_X:	.EQU	RT_28800-RATE_TABLE+4
RT_21600_X:	.EQU	RT_21600-RATE_TABLE+4
RT_20800_X:	.EQU	RT_20800-RATE_TABLE+4
RT_19200_X:	.EQU	RT_19200-RATE_TABLE+4
RT_16800_X:	.EQU	RT_16800-RATE_TABLE+4
RT_14400_X:	.EQU	RT_14400-RATE_TABLE+4
RT_300_X:	.EQU	RT_300-RATE_TABLE+4

 .ENDIF	;PARALLEL=0 (ie: Serial)

;
CNTB_1MS_EQU	.EQU ((CLOCK_FREQUENCY*10)/(1000)+5)/10 ; 1 ms Timer Latch
CNTB_1MS:       .DW ((CLOCK_FREQUENCY*10)/(1000) + 5)/10 ;1 msTimer Latch
;
SLOW_CLOCK:     .EQU    CLOCK_FREQUENCY/2       ; External Memory Clock f
;
Mult_value:     .DB     CLOCK_FREQUENCY/2*16/1843210    ;used in DTE

  .IFDEF	X2CLOCK				;For X2CLOCK (26.2,28.2MHz)
X_VAL:	.DB	(CLOCK_FREQUENCY/10000)/8/2	; used in DELAY_X...
  .ELSE						;Not X2CLOCK
   .IF (CLOCK_FREQUENCY < 22118400)		;
X_VAL:	.DB	(CLOCK_FREQUENCY/10000)/8	; used in DELAY_X...
   .ELSE					;
X_VAL:	.DB	FFH				; overflow use MAX value !!
   .ENDIF					;
  .ENDIF					;End X2CLOCK

MK_PER_TABLE1:
	; The numbers of bits in the comments are the delay between TXFNE bit
	; going from 1 to 0 and writing next data into TBUFFER
	; This delay should be from 9 bit to 15bit time
	; We adopt 12 bit time.
 .DB	64,0		        ;(0) 300 bps !! Dummy entry since we can't
				;                 have this speed in V.42
 .DB 26-1,>(00*((CLOCK_FREQUENCY/100)+5)/1000);(1) 600bps;    26.00ms ( 16 bits)
 .DB 13-1,>(40*((CLOCK_FREQUENCY/100)+5)/1000);(2)  1200 bps; 13.40ms ( 16 bits)
 .DB  6-1,>(70*((CLOCK_FREQUENCY/100)+5)/1000);(3)  2400 bps;  5.70ms (~14 bits)
 .DB  3-1,>(40*((CLOCK_FREQUENCY/100)+5)/1000);(4)  4800 bps;  3.40ms (~16 bits)
 .DB  1-1,>(70*((CLOCK_FREQUENCY/100)+5)/1000);(5)  9600 bps;  1.70ms (~16 bits)
 .DB  1-1,>(48*((CLOCK_FREQUENCY/100)+5)/1000);(6) 12000 bps;  1.48ms (~18 bits)
 .DB  1-1,>(09*((CLOCK_FREQUENCY/100)+5)/1000);(7) 14400 bps;  1.09ms (~16 bits)
 .DB  2-1,>(50*((CLOCK_FREQUENCY/100)+5)/1000);(8)  7200 bps;  2.50ms ( 18 bits)

 .DB  0-1,>(00*((CLOCK_FREQUENCY/100)+5)/1000);(9) 16800 bps;  1.00ms (~17 bits)
 .DB  0-1,>(97*((CLOCK_FREQUENCY/100)+5)/1000);(A) 19200 bps;  0.97ms (~19 bits)
 .DB  0-1,>(93*((CLOCK_FREQUENCY/100)+5)/1000);(B) 21600 bps;  0.93ms ( 20 bits)
 .DB  0-1,>(85*((CLOCK_FREQUENCY/100)+5)/1000);(C) 24000 bps;  0.85ms (~20 bits)
 .DB  0-1,>(80*((CLOCK_FREQUENCY/100)+5)/1000);(D) 26400 bps;  0.80ms (~21 bits)
 .DB  0-1,>(76*((CLOCK_FREQUENCY/100)+5)/1000);(E) 28800 bps;  0.76ms (~22 bits)
 .IFDEF V34_PLUS			      ;33.6K Speed enabled 
 .DB  0-1,>(70*((CLOCK_FREQUENCY/100)+5)/1000);(F) 31200 bps;  0.70ms (~22 bits) ;V34001
 .DB  0-1,>(65*((CLOCK_FREQUENCY/100)+5)/1000);(?) 33600 bps;  0.65ms (~22 bits) ;V34001
 .ENDIF
 .IFDEF	K56PLUS			; If K56Plus is enabled ;;k56?
 .DB  0-1,>(69*((CLOCK_FREQUENCY/100)+5)/1000);(11) 32000 bps;  0.69ms (~22 bits) ;;K56?
 .DB  0-1,>(65*((CLOCK_FREQUENCY/100)+5)/1000);(12) 34000 bps;  0.65ms (~22 bits)
 .DB  0-1,>(61*((CLOCK_FREQUENCY/100)+5)/1000);(13) 36000 bps;  0.61ms (~22 bits)
 .DB  0-1,>(58*((CLOCK_FREQUENCY/100)+5)/1000);(14) 38000 bps;  0.58ms (~22 bits)
 .DB  0-1,>(55*((CLOCK_FREQUENCY/100)+5)/1000);(15) 40000 bps;  0.55ms (~22 bits)
 .DB  0-1,>(52*((CLOCK_FREQUENCY/100)+5)/1000);(16) 42000 bps;  0.52ms (~22 bits)
 .DB  0-1,>(50*((CLOCK_FREQUENCY/100)+5)/1000);(17) 44000 bps;  0.50ms (~22 bits)
 .DB  0-1,>(48*((CLOCK_FREQUENCY/100)+5)/1000);(18) 46000 bps;  0.48ms (~22 bits)
 .DB  0-1,>(46*((CLOCK_FREQUENCY/100)+5)/1000);(19) 48000 bps;  0.46ms (~22 bits)
 .DB  0-1,>(44*((CLOCK_FREQUENCY/100)+5)/1000);(1A) 50000 bps;  0.44ms (~22 bits)
 .DB  0-1,>(42*((CLOCK_FREQUENCY/100)+5)/1000);(1B) 52000 bps;  0.42ms (~22 bits)
 .DB  0-1,>(41*((CLOCK_FREQUENCY/100)+5)/1000);(1C) 54000 bps;  0.41ms (~22 bits)
 .DB  0-1,>(39*((CLOCK_FREQUENCY/100)+5)/1000);(1D) 56000 bps;  0.39ms (~22 bits)
 .DB  0-1,>(38*((CLOCK_FREQUENCY/100)+5)/1000);(1E) 58000 bps;  0.38ms (~22 bits)
 .DB  0-1,>(37*((CLOCK_FREQUENCY/100)+5)/1000);(1F) 60000 bps;  0.37ms (~22 bits)
 .ENDIF	   			;End of K56PLUS

	; Since TXFNE in the old RC32DP (earlier than R6639-21) and one in
	; the RC32DPL(earlier than C26-D code) don't work, the other 
	; method which uses TDBE instead of TXFNE  should be adopted. 
	; Of course, using TXFNE is more reliable.
	; 
	; The numbers of bits in the comments are the delay between TDBE bit
	; going from 0 to 1 and writing next data into TBUFFER
	; These delays were desided by cut-and-try.
	; The length of the mark bits sent by the modem is 14 bit.
	; However only when 12000bps, the lengh of the mark bits exceeds 16bits
	; intermittently.
MK_PER_TABLE2:
 .DB	64,0		        ;(0) 300 bps !! Dummy entry since we can't
				;                 have this speed in V.42
 .DB 26-1,>(00*((CLOCK_FREQUENCY/100)+5)/1000);(1)   600 bps; 26.0 ms (16 bits)
 .DB 13-1,>(40*((CLOCK_FREQUENCY/100)+5)/1000);(2)  1200 bps; 13.4 ms (16 bits)
 .DB  6-1,>(70*((CLOCK_FREQUENCY/100)+5)/1000);(3)  2400 bps;  6.7 ms (16 bits)
 .DB  3-1,>(40*((CLOCK_FREQUENCY/100)+5)/1000);(4)  4800 bps;  3.4 ms (16 bits)
 .DB  1-1,>(70*((CLOCK_FREQUENCY/100)+5)/1000);(5)  9600 bps;  1.7 ms (16 bits)
 .DB  1-1,>(60*((CLOCK_FREQUENCY/100)+5)/1000);(6) 12000 bps;  1.6 ms (19 bits)
 .DB  1-1,>(00*((CLOCK_FREQUENCY/100)+5)/1000);(7) 14400 bps;  1.0 ms (14 bits)
 .DB  2-1,>(50*((CLOCK_FREQUENCY/100)+5)/1000);(8)  7200 bps;  2.5 ms (18 bits)

  .ENDIF				


