;**************************************************************************
;*											*
;* 	TITLE: 		WF96PROF.ASM							*
;*											*
;* 	PURPOSE: 	Provides factory profiles, NVM revision,			*
;*			default OEM_STRAP and S80 to be included			*
;*			in NVM module.							*
;*			This file can be modified by the OEM to be used			*
;*			by ConfigurACE to generate a modified target			*
;*			code.								*
;*											*
;*	AUTHOR:		Pierre Durin							*
;*											*
;*	REVISION HISTORY:								*
;*											*
;*	06JUL92	  PDU	Created								*
;*	05MAY93		Add Cellular TX and Equalizer Sreg 201				*
;*											*
;**************************************************************************
;	WARNING FOR USERS OF CONFIGURACE						;
;	--------------------------------						;
;	The file PRODUCT.TXT allows you to set pre-defined conditional			;
;	options for each product listed in the main menu.				;
;	When loading either this file or the country parameters files with;
;	ConfigurACE, if you don't have PRODUCT.TXT file in the same			;
;	directory, you will have to answer questions regarding the			;
;	conditional assembly options.							;
;**************************************************************************


DEFAULT_OEM_STRAP:
; This byte is copied to variable OEM_STRAP in RAM (location $48)
; at warm start.
;
; It is a bit mapped option flag

; Bit 0 AUDIO_PB4_PB5
; Bit 1 AUDIO_PE2_PE3
; Bit 2 PSEUDO_DIRECT
; Bit 3 FAX_DISABLE
; Bit 4 CLASS2_DISABLE
; Bit 5 USE_VOICEIA
; Bit 6 Bandlimit_MOH 
; Bit 7 SleepDisabled

; Default values for OEM_STRAP flags


.IF WlessConfig=Cellular
   .IFDEF ACF
	.DB   01000101B		; Cellular uses PB4/PB5
				; ACF defaults to Pseudo direct and no sleep
   .ELSE
	.DB   01000001B		; Cellular uses PB4/PB5
   .ENDIF ;ACF
.ELSE
   .IFDEF ACF
      .IFNDEF ACFSP2		; For L8144 DP
	.DB   11100110B		; Landline uses PE2/PE3
				; ACF defaults to Pseudo direct and no sleep
      .ELSE			; For L8246 or higher DP
	.DB   01100110B		; Landline uses PE2/PE3
				; ACFSP2 defaults to Pseudo direct and sleep
      .ENDIF
   .ELSE
	.DB   01000010B		; Landline uses PE2/PE3
   .ENDIF ;ACF
.ENDIF 				; End of Cellular


; Bit 0	 Disable StopModeON		defined in EQU - SYSFLG10 bit 1
; 					If set C39 stopmode is enabled, else disabled

ConfigValue:	.DB	00000000B	;Default Stopmode OFF

;****************************************************************************
;****	NVM REVISION HISTORY FOR WF96 						**
;****	----------------------------						**
;****							    			**
;****	Code version		|     rev	|  Date	    			**
;****	------------------------|---------------|-----------			**
;****	V1.002 (ACL)		|	L	| 15-DEC-92 			**
;****	V1.10  (ACW)		|	L	| 22-DEC-92 			**
;****	V1.15  (ACW)		|	M	| 26-FEB-93 			**
;****	V1.290 (ACL)		|	N	| 22-FEB-93 			**
;****	V1.297 (ACL)		|	O	| 03-MAY-93 			**
;****	V1.23-ACW / V1.321-ACL	|	P	| 18-JUN-93 			**
;****	V1.30-ACW / V1.400-ACL	|	Q	| 04-AUG-93 			**
;****	>v1.500 for ACLW	|	R	| 03-MAR-94			**
;****  	Added SerialNum variable|               |          			**
;****	7 bytes for 7 digits    |               |         			**
;****	Save RAM block to NVM	|       S	|    ?    			**
;****	Save +MS params		|	U	| 14-NOV-94   			**
;****   default to &C1&D2&S1	|	X	| 15-MAR-95
;****   default to &S0		|	Y	| 22-MAR-95
;****************************************************************************
;	WARNING FOR USERS OF CONFIGURACE		    			*
;	--------------------------------		    			*
; 	This file is intended to be modified by the user and interpreted	*
;	directly by ConfigurACE.						*
;	Don't forget to change the NVM revision byte, to test the new code	*
;	generated by ConfigurACE, this will allow the EEPROM to be reset  	*
;	to the new default values you have defined here.		  	*
;****************************************************************************
;NOTE: Now the 64K ROM version will only use a 2Kx1 NVM so it must always   	*
;      have a different NVM rev. from the 128K version.  This is necessary  	*
;      because if a board that has been running on 128K switches to the 64K 	*
;      version, it must reinitialize the NVM or a lockup may result.	       	*
;      So lower case is used for 64K version and upper case for 128K version	*
;****************************************************************************

NVM_REV:	.DB	'e'		;NVM Revision Letter for 2Kx1 NVM 


;****************************************************************************
;
;S register default table
;------------------------
SREG_TABLE:
	.DB	2			;S0: Auto answer (Enable)
	.DB	0			;S1: Ring counter
	.DB	'+'			;S2: ESC sequence character "+"
	.DB	13			;S3: Carriage Return Char <CR>
	.DB	10			;S4: Line Feed Char <LF>
	.DB	8			;S5: Backspace Char <BS>
	.DB	4			;S6: Blind Dial (Second)
	.DB	50			;S7: Wait for Carrier (Second)
	.DB	2			;S8: Pause time for dial delay (Second)
	.DB	6			;S9: CD Response Time (1/10 Second)
	.DB	14			;S10: Lost Carrier to hangup (1/10 Sec)
	.DB	95			;S11: DTMF timing for US only
	.DB	50			;S12: ESC code guard time (1/50 Sec)
	.DB	0			;S13: Not used

	.DB	10001010B		;S14: Bit mapped option
					;B0: Not used
					;B1: Enable Command Echo - ATE1
					;B2: Enable Result Code - ATQ0
					;B3: Long form result code - ATV1
					;B4: Not used
					;B5: Tone Dial - ATT
					;B6: Not used
					;B7: Enable Originate Mode - ATO

	.DB	0			;S15: Not used

	.DB	0			;S16: Bit mapped test option
					;B0: Disable LAL - AT&T1
					;B1: Not used
					;B2: Disable LDL - AT&T3
					;B3: Loop Back Off
					;B4: Disable to Initiate a RDL - AT&T6
					;B5: Disable to initiate a RDL - AT&T7
					;B6: Disable LAL/L3 - AT&T8
					;B7: Not used

	.DB	0			;S17: Not used

	.DB	0			;S18: Test timer - unlimited test time

        .DB     0                       ;S19: AutoSync Pararameters
        .DB     0                       ;S20: Autosync HDLC Addr/BSC Sync

	.DB	00110100B		;S21: Bit mapped option
					;B0: Select telephone jack - AT&J0
					;B1: Not used
					;B2: CTS always on - AT&R1
					;B3-B4: DTR option - AT&D2
					;B5: DCD option - AT&C1
					;B6: DSR option - AT&S0
					;B7: Disable long space disc - ATY0

	.DB	01110101B		;S22: Bit mapped option
					;B0-B1: Low speaker volume - ATL1
					;B2-B3: Spk on until carr det - ATM1
					;B4-B5-B6: Result code type - ATX4
					;B7: Not used

	.DB	00110110B		;S23: Bit mapped option
					;B0: Grant RDL from remote 
					;(MUST ALWAYS BE DISABLED!)
					;B1-B2-B3: DTE speed - 2400bps
					;B4-B5: DTE parity - None
					;B6-B7: Select no guard tone - AT&G0

	.DB	0			;S24: Sleep mode inactivity timer (10s)
	.DB	5			;S25: Delay to DTR (Sec & 1/100 Sec)
	.DB	1			;S26: RTS to CTS delay (1/100 Sec)

	.DB	00001001B		;S27: Bit mapped option
					;B0-B1,B3: Asyn mode - AT&Q5
					;B2: Not used
					;B4-B5: Sync clock select - AT&X0
					;B6: Select CCITT mode - ATB0
					;B7: Not used

	.DB	0			;S28: Bit mapped options
					;B0-B2: Not used
					;B3-B4:	Pulse Ratio (AT&P0)
					;B5:	Auxiliary Mode (AT%M0)
					;B6-B7:	MNP10 negotiation speed (*H0)

	.DB	0			;S29: Flash Time (ms)

	.DB	0			;S30: Inactivity Timer (min)

	.DB	11000010B		;S31: Bit mapped options
					;B0:	Single line connect msg (\V0)
					;B1:	Auto Speed Detection (N1)
					;B2-B3:	Extended result codes (W0)
					;B4-B5: Caller ID Mode select (#CID=0)
					;B6-B7: Reserved

	.DB	$11			;S32: XON flow control character (DC1)
	.DB	$13			;S33: XOFF flow control character (DC3)
	.IFDEF ISDN
	.DB	3			;S36: Fallback Options
	.ELSE
	.DB	7			;S36: Fallback Options
	.ENDIF
	.DB	0			;S37: Desired line speed
	.DB	20			;S38: Delay before forced hangup
	.DB	3			;S39: Flow Control (&K6)

	.DB	01101000B		;S40: Bit mapped options
					;B0-B1: Extended services (-K0) 
					;B2: Cell. Power Adj.  ()M0)
					;B3-B5:	Break Handling (\K5)
					;B6-B7:	MNP Max Block Size (\A1)
	.IFDEF ISDN
	.DB	11000000B
	.ELSE
	.DB	11000011B		;S41: Bit mapped options
	.ENDIF				;B0-B1:	Compression Control (%C0)
					;B2:	Auto retrain enable (%E1)
					;B3:	DCE-DCE flow control (\G0)
					;B4:	MNP Block Mode (\L0)
					;B5:	DTE rate change (\J0)
					;B6:	Online FB/FF disable (%E1)
					;B7: Fallback Modulation (-Q1)

	.DB	138			;S46: V.42bis compression control

	.IFDEF ISDN
	.DB	0			;S48: V.42 negotiation action
	.ELSE
	.DB 7
	.ENDIF
	.DB	128			;S82: Break control
	.DB	0			;S86: Call failure indication
	.DB	10			;S91: PSTN Transmit level
	.DB	10			;S92: FAX  Transmit level
	.DB	0			;S95: More extended result code control

.IFDEF NO_PUMP	; NO_PUMP ISDN code
	.DB	8			;Set ExternDigData
.ELSE
	.DB	0			;S200: Bit mapped options
					;B0-B1: Non-Standard DTE disable (%N0)
					;B2-B5: Not used
					;B6-B7: Auto-Reliable buf. not used (\C0)
.ENDIF

	.DB	00110010B		;S201: Bit mapped options
					;B0-B4:	Tx level (@M0 = -18)
					;B5:	Equalizer (:E1)
					;B6:	Unused
					;B7: 	no EC (EC_MODE=0)

	.DB	0			;S202: Not Used



	.DB	13			;S210: Symbol Rates & Asym Rate Select
					;B0-B2: Symbol rate select
					;	000 - 2400 only
					;	001 - 2400 only
					;	010 - 2400,2800 
					;	011 - 2400,2800,3000
					;	100 - 2400,2800,3000,3200
					;	101 - 2400,2800,3000,3200,3429
					;	      (default)
					;B3:	Asym Rate Select 
					;	0 - v.34 asym rates disabled 
					;	1 - v.34 asym rates enabled 
					;		(default)

SREG_FLG_LEN:	.EQU	$-SREG_TABLE		;Length of S register table

;S register default table 1
;--------------------------
SREG1_TABLE:
	.DB	2			;S0: Auto answer (Enable)
	.DB	0			;S1: Ring counter
	.DB	'+'			;S2: ESC sequence character "+"
	.DB	13			;S3: Carriage Return Char <CR>
	.DB	10			;S4: Line Feed Char <LF>
	.DB	8			;S5: Backspace Char <BS>
	.DB	4			;S6: Blind Dial (Second)
	.DB	50			;S7: Wait for Carrier (Second)
	.DB	2			;S8: Pause time for dial delay (Second)
	.DB	6			;S9: CD Response Time (1/10 Second)
	.DB	14			;S10: Lost Carrier to hangup (1/10 Sec)
	.DB	95			;S11: Not used
	.DB	50			;S12: ESC code guard time (1/50 Sec)
	.DB	0			;S13: Not used

	.DB	10001010B		;S14: Bit mapped option
					;B0: Not used
					;B1: Enable Command Echo - ATE1
					;B2: Enable Result Code - ATQ0
					;B3: Long form result code - ATV1
					;B4: Not used
					;B5: Tone Dial - ATT
					;B6: Not used
					;B7: Enable Originate Mode - ATO

	.DB	0			;S15: Not used

	.DB	0			;S16: Bit mapped test option
					;B0: Disable LAL - AT&T1
					;B1: Not used
					;B2: Disable LDL - AT&T3
					;B3: Loop Back Off
					;B4: Disable to Initiate a RDL - AT&T6
					;B5: Disable to initiate a RDL - AT&T7
					;B6: Disable LAL/L3 - AT&T8
					;B7: Not used

	.DB	0			;S17: Not used

	.DB	0			;S18: Test timer - unlimited test time

        .DB     0                       ;S19: AutoSync Pararameters
        .DB     0                       ;S20: Autosync HDLC Addr/BSC Sync

	.DB	00110100B		;S21: Bit mapped option
					;B0: Select telephone jack - AT&J0
					;B1: Not used
					;B2: CTS always on - AT&R1
					;B3-B4: DTR option - AT&D2
					;B5: DCD follows the state of carrier - AT&C1
					;B6: DSR option - AT&S0
					;B7: Disable long space disc - ATY0

	.DB	01110101B		;S22: Bit mapped option
					;B0-B1: Low speaker volume - ATL1
					;B2-B3: Spk on until carr det - ATM1
					;B4-B5-B6: Result code type - ATX4
					;B7: Not used

	.DB	00110110B		;S23: Bit mapped option
					;B0: Grant RDL from remote (Disabled)
					;B1-B2-B3: DTE speed - 2400bps
					;B4-B5: DTE parity - None
					;B6-B7: Select no guard tone - AT&G0

	.DB	0			;S24: Sleep mode inactivity timer (10s)
	.DB	5			;S25: Delay to DTR (Sec & 1/100 Sec)
	.DB	1			;S26: RTS to CTS delay (1/100 Sec)

	.DB	00001001B		;S27: Bit mapped option
					;B0-B1,B3: Asyn mode - AT&Q5
					;B2: Not used
					;B4-B5: Sync clock select - AT&X0
					;B6: Select CCITT mode - ATB0
					;B7: Not used

	.DB	0			;S28: Bit mapped options
					;B0-B2: Not used
					;B3-B4:	Pulse Ratio (AT&P0)
					;B5:	Auxiliary Mode (AT%M0)
					;B6-B7:	MNP10 negotiation speed (*H0)

	.DB	0			;S29: Flash Time (ms)

	.DB	0			;S30: Inactivity Timer (min)

	.DB	11000010B		;S31: Bit mapped options
					;B0:	Not used
					;B1:	Auto Speed Detection (N1)
					;B2-B3:	Extended result codes (W0)
					;B4-B7: Not used
					;B6-B7: BTLZ compression direction (%%)

	.DB	$11			;S32: XON flow control character (DC1)
	.DB	$13			;S33: XOFF flow control character (DC3)
	.IFDEF ISDN
	.DB	3			;S36: Fallback Options
	.ELSE
	.DB	7
	.ENDIF
	.DB	0			;S37: Desired line speed
	.DB	20			;S38: Delay before forced hangup
	.DB	3			;S39: Flow Control (&K6)

	.DB	10101000B		;S40: Bit mapped options
					;B0-B1: Extended services (-K0) 
					;B2: Cell. Power Adj.  ()M0)
					;B3-B5:	Break Handling (\K5)
					;B6-B7:	MNP Max Block Size (\A2)

	.IFDEF ISDN
	.DB	11000000B		;S41: Bit mapped options
	.ELSE
	.DB 11000011B
	.ENDIF
					;B0-B1:	Compression Control (%C0)
					;B2:	Auto retrain disable (%E2)
					;B3:	DCE-DCE flow control (\G0)
					;B4:	MNP Block Mode (\L0)
					;B5:	DTE rate change (\J0)
					;B6:	Online FB/FF enable (%E2)
					;B7:	Not used

	.DB	138			;S46: V.42bis compression control

	.IFDEF ISDN
	.DB	0			;S48: V.42 negotiation action
	.ELSE
	.DB	7
	.ENDIF
	.DB	128			;S82: Break control
	.DB	0			;S86: Call failure indication
	.DB	10			;S91: PSTN Transmit level
	.DB	10			;S92: FAX  Transmit level
	.DB	0			;S95: More extended result code control

.IFDEF NO_PUMP	; NO_PUMP ISDN code
	.DB	8			;Set ExternDigData
.ELSE
	.DB	0			;S200: Bit mapped options
					;B0-B1: Non-Standard DTE disable (%N0)
					;B2-B5: Not used
					;B6-B7: Auto-Reliable buf. not used (\C0)
.ENDIF

	.DB	00110010B		;S201: Bit mapped options
					;B0-B4:	Tx level (@M18)
					;B5:	Equalizer (:E1)
					;B6:	Unused
					;B7: 	no EC (EC_MODE=0)

	.DB	0			;S202: Not used


	.DB	13			;S210: Symbol Rates & Asym Rate Select
					;B0-B2: Symbol rate select
					;	000 - 2400 only
					;	001 - 2400 only
					;	010 - 2400,2800 
					;	011 - 2400,2800,3000
					;	100 - 2400,2800,3000,3200
					;	101 - 2400,2800,3000,3200,3429
					;	      (default)
					;B3:	Asym Rate Select 
					;	0 - v.34 asym rates disabled 
					;	1 - v.34 asym rates enabled 
					;		(default)


; Include the RLSD table
.INCLUDE	WF96RLSD.ASM


;----------------------------------------------------------------------------;
;	This is the user modifiable table for changing the default           ;
;	operating frequency for the VFC DPL data pumps                       ;
;	Valid Values are:			                             ;
; 		0.... 20.160 MHz                                             ;
; 		1.... 18.144 MHz                                             ;
; 		2.... 16.128 MHz                                             ;
; 		3.... 14.112 MHz                                             ;
; 		4.... 12.096 MHz                                             ;
;----------------------------------------------------------------------------;
;----------------------------------------------------------------------------;
DAACODE_TABLE:
;
; This table is used by the country recognition firmware to map
; a particular 8bit code read from the DAA (see Designer's Guide)
; to an appropriate country code, as defined in the country files.
;
;                         Country      
;               DAA code   code
;       -------------------------------------------------
        .DB   00000000B,  22          ;U.S and Canada	1-$00	

        .DB   00010000B,  43          ;Japan     	2-$10

        .DB   00100000B,  22          ;U.S and Canada	3-$20   Why is this one here?
        .DB   00100001B,  02          ;Belgium   	4-$21       
        .DB   00100010B,  04          ;Finland	 	5-$22
        .DB   00100011B,  05          ;France    	6-$23 
  
        .DB   00100101B,  08          ;Italy     	7-$25 
        .DB   00100110B,  10          ;Netherlands 	8-$26    
        .DB   00100111B,  14          ;Sweden		9-$27	
        .DB   00101000B,  15          ;Switzerland      10-$28    
        .DB   00101001B,  16          ;UK          	11-$29
        .DB   00101010B,  11          ;Norway		12-$2A
 

; DAA codes for the following countries are not defined at present,
; They are included here so that they can be modified as desired without
; extending the length of the file, which would cause Configurace to error.
; Note the 00000000B entry will not be interpreted since the table
; search will already have found this entry at the top of the table.

        .DB   00000000B,  01          ;Austria	13-xx
        .DB   00000000B,  03          ;Denmark	14-xx
        .DB   00000000B,  06          ;Germany	15-XX
        .DB   00000000B,  07          ;Ireland	16-XX
        .DB   00000000B,  09          ;Luxembourg 17-xx

        .DB   00000000B,  12          ;Portugal	18-xx
        .DB   00000000B,  13          ;Spain	19-xx
        .DB   00000000B,  20          ;Canada	20-xx
        .DB   00000000B,  21          ;Mexico	21-xx
        .DB   00000000B,  30          ;India	22-xx
        .DB   00000000B,  40          ;Australia 23-xx
        .DB   00000000B,  41          ;China	24-xx

        .DB   00000000B,  42          ;Hong Kong 25-xx
        .DB   00000000B,  44          ;Korea     26-xx
        .DB   00000000B,  45          ;Philippines 27-xx
        .DB   00000000B,  46          ;Taiwan	28-xx
;Pad to 32 countries
        .DB   00000000B,  00          ;Not Used 29-xx
        .DB   00000000B,  00          ;Not Used 30-xx
        .DB   00000000B,  00          ;Not Used 31-xx
        .DB   00000000B,  00          ;Not Used 32-xx

; Notes
;-------
;
; 1. XXX11111B is normally reserved to mean DAA fitted but linecord absent.
;
; 2. The modem can be forced to generate an error when dialling with no DAA
;    present (DAA code = $FF), by changing one of the above to lines to:
;        .DB   11111111B, 255         ;Non-existent country code generates ERROR
;    This is not done by default so that the modem will dial if the
;    Country Code Recognition hardware is not implemented.


DAACODE_TABLE_SIZE: .EQU ($-DAACODE_TABLE)


;******************************************************************************
;			ISDN_RELAYS_CODE
;	
;    RA (Pump) 	= OFFHokk relay   to take the line with the handset
;    RB (Pump) 	= Not Used
;    PE0	= Caller ID       to connect the line to the Pump
;    PE1	= PhoneRing       to generate the telephone ring frequency
;    PE2	= RingLine        to generate the telephone ring cadence
;    PE3	= Voice           to power up the handset
;
;
; The Table below defines the relays control bits 
; 
; 
; Name of the Control bit	Voice	CID	RLY4	RLY3	RLY2	RLY1	
; Controled Pin if ISDN		PE3	PE0	RB	PE2	PE1	RA
; Name of the Relay		Voice	CLID	NotUsed	Ring	Phone	OH
;							line	Ring
; The Table below defines the logical state of all relays
;
;      Relay		VOICE	CID	Not	RING	PHONE	OFFHOOK	
;State					Used	LINE	RING
;
;ISDN Default	   	1	0	0	0	0	0			
;Pots DTMF Detect  	1	1	0	0	0	0		
;Ring Cadence On   	1	0	0	1	1	0		
;Ring Cadence OFF  	1	0	0	0	0	0		
;Ring Frequency ON 	1	0	0	1	1	0		
;Ring Frequency OFF	1	0	0	1	0	0			
;
;
;
;
;******************************************************************************
.IFDEF ISDN
ISDN_RELAYS_CODE:
                .DB	 $14
                .DB	 $04
                .DB	 $12
                .DB	 $14
                .DB	 $12
                .DB	 $10
ISDN_RELAY_SIZE:	 .EQU ($-ISDN_RELAYS_CODE)	 
.ENDIF
